@@ -24,7 +24,6 @@
 
 #include <glib/gi18n.h>
 
-#include "seahorse-context.h"
 #include "seahorse-source.h"
 #include "seahorse-gtkstock.h"
 #include "seahorse-util.h"
@@ -77,7 +76,7 @@ calc_name (SeahorsePgpKey *self)
 	GList *uids = seahorse_pgp_key_get_uids (self);
 	return uids ? seahorse_pgp_uid_calc_label (seahorse_pgp_uid_get_name (uids->data),
 	                                           seahorse_pgp_uid_get_email (uids->data),
-	                                           seahorse_pgp_uid_get_comment (uids->data)) : "";
+	                                           seahorse_pgp_uid_get_comment (uids->data)) : g_strdup ("");
 }
 
 static gchar* 
@@ -86,7 +85,7 @@ calc_markup (SeahorsePgpKey *self, guint flags)
 	GList *uids = seahorse_pgp_key_get_uids (self);
 	return uids ? seahorse_pgp_uid_calc_markup (seahorse_pgp_uid_get_name (uids->data),
 	                                            seahorse_pgp_uid_get_email (uids->data),
-	                                            seahorse_pgp_uid_get_comment (uids->data), flags) : "";
+	                                            seahorse_pgp_uid_get_comment (uids->data), flags) : g_strdup ("");
 }
 
 /* -----------------------------------------------------------------------------
@@ -103,21 +102,27 @@ _seahorse_pgp_key_get_uids (SeahorsePgpKey *self)
 static void
 _seahorse_pgp_key_set_uids (SeahorsePgpKey *self, GList *uids)
 {
+	guint index;
+	GQuark id;
 	GList *l;
 	
 	g_return_if_fail (SEAHORSE_IS_PGP_KEY (self));
 
+	id = seahorse_object_get_id (SEAHORSE_OBJECT (self));
+	
 	/* Remove the parent on each old one */
-	for (l = self->pv->uids; l; l = g_list_next (l)) 
+	for (l = self->pv->uids; l; l = g_list_next (l))
 		seahorse_object_set_parent (l->data, NULL);
 
 	seahorse_object_list_free (self->pv->uids);
 	self->pv->uids = seahorse_object_list_copy (uids);
-
+	
 	/* Set parent and source on each new one, except the first */
-	for (l = self->pv->uids ? g_list_next (self->pv->uids) : NULL;
-	     l; l = g_list_next (l))
-		seahorse_object_set_parent (l->data, SEAHORSE_OBJECT (self));
+	for (l = self->pv->uids, index = 0; l; l = g_list_next (l), ++index) {
+		g_object_set (l->data, "id", seahorse_pgp_uid_calc_id (id, index), NULL);
+		if (l != self->pv->uids)
+			seahorse_object_set_parent (l->data, SEAHORSE_OBJECT (self));
+	}
 	
 	g_object_notify (G_OBJECT (self), "uids");
 }
@@ -140,7 +145,7 @@ _seahorse_pgp_key_set_subkeys (SeahorsePgpKey *self, GList *subkeys)
 	seahorse_object_list_free (self->pv->subkeys);
 	self->pv->subkeys = seahorse_object_list_copy (subkeys);
 	
-	id = seahorse_pgp_key_calc_cannonical_id (seahorse_pgp_subkey_get_keyid (subkeys->data));
+	id = seahorse_pgp_key_canonize_id (seahorse_pgp_subkey_get_keyid (subkeys->data));
 	g_object_set (self, "id", id, NULL); 
 	
 	g_object_notify (G_OBJECT (self), "subkeys");
@@ -297,6 +302,7 @@ seahorse_pgp_key_object_dispose (GObject *obj)
 	/* Free all the attached UIDs */
 	for (l = self->pv->uids; l; l = g_list_next (l))
 		seahorse_object_set_parent (l->data, NULL);
+
 	seahorse_object_list_free (self->pv->uids);
 	self->pv->uids = NULL;
 
@@ -401,38 +407,50 @@ seahorse_pgp_key_class_init (SeahorsePgpKeyClass *klass)
  */
 
 GQuark
-seahorse_pgp_key_calc_cannonical_id (const gchar *id)
+seahorse_pgp_key_canonize_id (const gchar *keyid)
+{
+	gchar *str;
+	GQuark id;
+	
+	str = seahorse_pgp_key_calc_id (keyid, 0);
+	g_return_val_if_fail (str, 0);
+	
+	id = g_quark_from_string (str);
+	g_free (str);
+	
+	return id;
+}
+
+gchar*
+seahorse_pgp_key_calc_id (const gchar *keyid, guint index)
 {
 	guint len;
-	GQuark keyid;
-	gchar *t;
 	
-	g_return_val_if_fail (id, 0);
-	len = strlen (id);
+	g_return_val_if_fail (keyid, 0);
+	len = strlen (keyid);
     
 	if (len < 16)
-		g_message ("invalid keyid (less than 16 chars): %s", id);
+		g_message ("invalid keyid (less than 16 chars): %s", keyid);
     
 	if (len > 16)
-		id += len - 16;
+		keyid += len - 16;
     
-	t = g_strdup_printf ("%s:%s", SEAHORSE_PGP_STR, id);
-	keyid = g_quark_from_string (t);
-	g_free (t);
-    
-	return keyid;
+	if (index == 0)
+		return g_strdup_printf ("%s:%s", SEAHORSE_PGP_STR, keyid);
+	else
+		return g_strdup_printf ("%s:%s:%u", SEAHORSE_PGP_STR, keyid, index);
 }
 
 const gchar* 
-seahorse_pgp_key_calc_rawid (GQuark keyid)
+seahorse_pgp_key_calc_rawid (GQuark id)
 {
-	const gchar* id, *rawid;
+	const gchar* keyid, *strid;
 	
-	id = g_quark_to_string (keyid);
-	g_return_val_if_fail (id != NULL, NULL);
+	strid = g_quark_to_string (id);
+	g_return_val_if_fail (strid != NULL, NULL);
 	
-	rawid = strchr (id, ':');
-	return rawid ? rawid + 1 : id;
+	keyid = strchr (strid, ':');
+	return keyid ? keyid + 1 : strid;
 }
 
 gchar*
